/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'templates', 'en-au', {
	button: 'Templates',
	emptyListMsg: '(No templates defined)',
	insertOption: 'Replace actual contents',
	options: 'Template Options',
	selectPromptMsg: 'Please select the template to open in the editor',
	title: 'Content Templates'
} );
